pub struct AppState {
pub config: Arc<AppConfig>,
pub renderer: Arc<FallbackRenderer>,
pub crawl_jobs: Arc<RwLock<HashMap<Uuid, CrawlJob>>>,
pub crawl_semaphore: Arc<Semaphore>,
}Expand description
Shared application state.
Fields
config: Arc<AppConfig>renderer: Arc<FallbackRenderer>crawl_jobs: Arc<RwLock<HashMap<Uuid, CrawlJob>>>crawl_semaphore: Arc<Semaphore>Implementations
Sourceimpl AppState
impl AppState
pub fn new(config: AppConfig) -> Self
Sourcepub async fn start_crawl_job(&self, req: CrawlRequest) -> Uuid
pub async fn start_crawl_job(&self, req: CrawlRequest) -> Uuid
Start a new crawl job and return its UUID. Spawns a background task that acquires the crawl semaphore before running.